Java Application Server Wizard
==============================

This wizard includes plugins which can monitor the major Java application servers, including:
 - Apache Tomcat
 - JBoss/Wildfly
 - Glassfish
 - Jetty
 - Weblogic

The first four of these share a plugin, check_jvm.jar, which should be usable with most JVMs. It operates by establishing a 
JMX connection to the server via a service URL provided on the command line. You can specify one or more checks, which are all
executed on the same connection.

Weblogic monitoring is provided via wlsagent. This was originally a community project developed by yannlambret, and has 
been updated to compile and run in a Java 7+ environment. This setup operates by running a daemon on the same machine as 
the weblogic server, which connects to it via JMX over T3. The plugin opens a cURL connection to the daemon to retrieve
monitoring information.

(The original source for wlsagent is available at 
https://code.google.com/archive/p/wlsagent/. 
The new source should be available in plugins/wlsagent.tar.gz in the same directory as this file.)

Using check_jvm.jar
===================

You can get the full help text by running
```
java -jar check_jvm.jar -h
```
This will give information as to what checks are available on whichever version you have.

To use check_jvm.jar, you will need the following information:
 - The service URL to your server's JMX port (the -s option)
 - Valid credentials for accessing JMX (-u/-p for username/password)
 - the "type" of your server (-t, one of "tomcat", "jboss", "glassfish", or "jetty")

You will also want to know which counters you want to monitor. For most servers, you will have access to counters for memory/CPU usage, the class count, the thread count, and uptime. You can get the full list by viewing the help text.

For example, if we wanted to get the total heap memory usage, we would run a check like:
```
java -jar check_jvm.jar -t <type> -s <service_URL> -u <username> -p <password> -C MemorySimpleHeap -w <threshold_in_bytes> -c <threshold_in_bytes>
```

A complete plugin call might look like:

```
java -jar check_jvm.jar -t tomcat -s 'service:jmx:rmi:///jndi/rmi://<host>:<port>/jmxrmi' -u 'monitorRole' -p 'monitor' -C MemorySimpleHeap -w 104857600 -c 209715200
```

This will alert WARNING if the JVM heap exceeds 100 MiB, or CRITICAL if it exceeds 200 MiB.

We can also run multiple checks on one connection by turning -w/-c/-C into comma-delimited lists. To add uptime monitoring to the last call:

```
java -jar check_jvm.jar -t tomcat -s 'service:jmx:rmi:///jndi/rmi://<host>:<port>/jmxrmi' -u 'monitorRole' -p 'monitor' -C MemorySimpleHeap,Uptime -w 104857600,:600000 -c 209715200,:300000
```

In addition to the rules above, this will also alert WARNING if the JVM has been alive for less than 10 minutes, or CRITICAL if it's been alive for less than 5 minutes.

Using wlsagent
==============

For full documentation on setting up the wlsagent daemon, see our documentation entitled "How to Monitor WebLogic with Nagios XI."

In short, you will need to:
 - Download wlsagent.tar.gz to your Weblogic machine
 - Extract the files somewhere permanent
 - Modify run.sh to listen on whatever (unused) port you prefer
 - Set/export the ORACLE_HOME environment variable
 - Run the jarbuilder at $ORACLE_HOME/wlserver/modules/com.bea.core.jarbuilder.jar
 - Copy wlclient.jar, wljmxclient.jar, and wlfullclient.jar to wlsagent/lib.
 - Run ./run.sh

Now that your wlsagent daemon is running, check_wlsagent.sh will use 3 positional arguments:
 - First, the hostname/IP Address of your wlsagent daemon. If running check_wlsagent.sh through NCPA, this is 127.0.0.1
 - Second, the port of the wlsagent daemon. By default, this is 9090
 - Third, the check information. This is passed as post data to cURL.

 The check information is passed as a &-delimited list. The exact invocations can be found by visiting https://code.google.com/archive/p/wlsagent/wikis/ or by looking at output from the configuration wizard. As an example, here's an invocation to check the number of JTA active transactions and also the JVM Heap usage:

```
 ./check_wlsagent <ip_address> 9090 'jta=ActiveTransations,15,30&jvm=UsedMemory,90,95'
```
This will alert WARNING if there are more than 15 active JTA transactions or if the heap is more than 90% used, or CRITICAL if there are more than 30 active transactions and the heap is more than 95% used.
